@@ -8,4 +8,4 @@ sys.path.append(os.path.join(os.path.dirname(__file__), '..', '..'))
 # print('Changing to ' + os.path.dirname(__file__))
 # os.chdir(os.path.dirname(__file__))
 # print(os.getcwd())
-from features_algorithms.accelerated_graph_features.src.accelerated_graph_features.feature_wrappers import *
+from accelerated_graph_features.feature_wrappers import *
